==> ofx2xlsmbr-0.99.2.tar.gz: ofx2xlsmbr-0.99.2/ofx2xlsmbr/ProsperarCore.py <==
from .factory.OFXReaderFactory import OFXReaderFactory
from .factory.XLSReaderFactory import XLSReaderFactory
from .factory.PDFReaderFactory import PDFReaderFactory
from .factory.XLSMWriterFactory import XLSMWriterFactory

import logging

logger = logging.getLogger(__name__)

class ProsperarCore():
    def run(self, files):
        #ler o caminho do arquivo e verificar se ele existe
        if (not files):
            logger.info('No files specified.')
            return

        xlsFiles = []
        ofxFiles = []
        pdfFiles = []

        for file in files:
            try:
                if ('.xls' in file.filename):
                    xlsFiles.append(file)
                elif ('.pdf' in file.filename):
                    pdfFiles.append(file)
                else:
                    ofxFiles.append(file)
            except AttributeError:
                if ('.xls' in file.name):
                    xlsFiles.append(file)
                elif ('.pdf' in file.name):
                    pdfFiles.append(file)
                else:
                    ofxFiles.append(file)

        logger.info(ofxFiles)
        logger.info(xlsFiles)
        logger.info(pdfFiles)

        #chamar o leitor ofx
        factoryOFX = OFXReaderFactory()
        readerController = factoryOFX.createReaderController()
        ofxBankStmts = readerController.read(factoryOFX, files=ofxFiles)

        #chamar o leitor xls
        factoryXLS = XLSReaderFactory()
        readerController = factoryXLS.createReaderController()
        xlsBankStmts = readerController.read(factoryXLS, files=xlsFiles)

        #chamar o leitor pdf
        factoryPDF = PDFReaderFactory()
        readerController = factoryPDF.createReaderController()
        pdfBankStmts = readerController.read(factoryPDF, files=pdfFiles)

        bankStmts = xlsBankStmts + ofxBankStmts + pdfBankStmts

        #chamar o escritor xlsm
        factory = XLSMWriterFactory()
        writerController = factory.createWriterController()
        return writerController.write(bankStmts, factory)

==> ofx2xlsmbr-0.99.3.tar.gz: ofx2xlsmbr-0.99.3/ofx2xlsmbr/ProsperarCore.py <==
from .factory.OFXReaderFactory import OFXReaderFactory
from .factory.XLSReaderFactory import XLSReaderFactory
from .factory.PDFReaderFactory import PDFReaderFactory
from .factory.XLSMWriterFactory import XLSMWriterFactory

from .utils.BankStatementAdder import BankStatementAdder

import logging

logger = logging.getLogger(__name__)

class ProsperarCore():
    def run(self, files):
        #ler o caminho do arquivo e verificar se ele existe
        if (not files):
            logger.info('No files specified.')
            return

        xlsFiles = []
        ofxFiles = []
        pdfFiles = []

        for file in files:
            try:
                if ('.xls' in file.filename):
                    xlsFiles.append(file)
                elif ('.pdf' in file.filename):
                    pdfFiles.append(file)
                else:
                    ofxFiles.append(file)
            except AttributeError:
                if ('.xls' in file.name):
                    xlsFiles.append(file)
                elif ('.pdf' in file.name):
                    pdfFiles.append(file)
                else:
                    ofxFiles.append(file)

        logger.info(ofxFiles)
        logger.info(xlsFiles)
        logger.info(pdfFiles)

        #chamar o leitor ofx
        factoryOFX = OFXReaderFactory()
        readerController = factoryOFX.createReaderController()
        ofxBankStmts = readerController.read(factoryOFX, files=ofxFiles)

        #chamar o leitor xls
        factoryXLS = XLSReaderFactory()
        readerController = factoryXLS.createReaderController()
        xlsBankStmts = readerController.read(factoryXLS, files=xlsFiles)

        #chamar o leitor pdf
        factoryPDF = PDFReaderFactory()
        readerController = factoryPDF.createReaderController()
        pdfBankStmts = readerController.read(factoryPDF, files=pdfFiles)

        bankStmt = None
        if ofxBankStmts:
            bankStmt = ofxBankStmts[0]
        elif xlsBankStmts:
            bankStmt = xlsBankStmts[0]
        elif pdfBankStmts:
            bankStmt = pdfBankStmts[0]

        adder = BankStatementAdder()

        for bs in ofxBankStmts:
            bankStmt = adder.add(bankStmt, bs)
        for bs in xlsBankStmts:
            bankStmt = adder.add(bankStmt, bs)
        for bs in pdfBankStmts:
            bankStmt = adder.add(bankStmt, bs)
        bankStmts = [bankStmt]

        #bankStmts = xlsBankStmts + ofxBankStmts + pdfBankStmts

        #chamar o escritor xlsm
        factory = XLSMWriterFactory()
        writerController = factory.createWriterController()
        return writerController.write(bankStmts, factory)
